@@ -9,7 +9,7 @@
 
 #include <jni.h>
 #include <gnome.h>
-#include <libgtk-java/jg_jnu.h>
+#include "jg_jnu.h"
 
 #ifndef _Included_org_gnu_gnome_PasswordDialog
 #define _Included_org_gnu_gnome_PasswordDialog
